js-initiator
============

A Django wrapper for our JavaScript library for initialising frontend page elements.

Compatibility
-------------

`js-initiator`' major.minor version number indicates the Django release it is compatible with. Currently this is Django 4.1.

Installation
------------

1. Install using `pip`:
  ```shell
  pip install js-initiator
  ```
2. Add `js_initator` to your `INSTALLED_APPS` setting:
   ```python
   INSTALLED_APPS = [
     # ...
     'js_initator'
     # ...
   ]
   ```
